@@ -36,12 +36,12 @@ def get_request_parameters_from_event(event: dict) -> dict:
     """Extracts all params from the event object.
     The order of precedence is: payload > path > query string
     returns a dictionary with all the parameters, with both camelCase and snake_case keys."""
-    all_params = get_payload_dict_from_event(event)
-    all_params.update(get_path_parameters_dict_from_event(event))
-    all_params.update(get_query_string_parameters_from_event(event))
-    all_params = {camel_to_snake(key): value for key, value in all_params.items()}
-    all_params.update({snake_to_camel(key): value for key, value in all_params.items()})
-    return all_params
+    all_parameters_dict = get_payload_dict_from_event(event)
+    all_parameters_dict.update(get_path_parameters_dict_from_event(event))
+    all_parameters_dict.update(get_query_string_parameters_from_event(event))
+    all_parameters_dict = {camel_to_snake(key): value for key, value in all_parameters_dict.items()}
+    all_parameters_dict.update({snake_to_camel(key): value for key, value in all_parameters_dict.items()})
+    return all_parameters_dict
 
 
 # TODO: test
@@ -74,8 +74,10 @@ def handler_decorator(logger):
     return decorator
 
 
+# TODO: should we auto detect user_jwt if not provided?
 def create_authorization_http_headers(user_jwt: str) -> dict:
     logger.start(object={"user_jwt": user_jwt})
+    #TODO check the validity of user_jwt and it is not None and raise exception, please do the same in all other functions.
     authorization_http_headers = {
         'Content-Type': 'application/json',
         'Authorization': AUTHORIZATION_PREFIX + user_jwt,
@@ -96,6 +98,8 @@ def get_user_jwt_from_event(event: dict) -> str:
 
 def create_return_http_headers() -> dict:
     logger.start()
+    # Adding "Access-Control-Allow-Origin" : "*" to take care of CORS from localhost
+    # TODO Do we need to add those? In which cases? try  adding crossDomain: true, to the request, 'Access-Control-Allow-Credentials': true to header
     return_http_headers = {
         "Content-Type": "application/json",
         "Access-Control-Allow-Origin": "*",
